@@ -3,6 +3,7 @@ from django.conf import settings
 
 
 class SortableConf(AppConf):
+    STATIC_URL = u'/static/'
     JQUERY_LIB = u"{}{}".format(
         getattr(settings, u'STATIC_URL', u'/static/'),
         u"sortable/js/jquery-2.1.0.min.js"
@@ -12,6 +13,12 @@ class SortableConf(AppConf):
         u"sortable/js/jquery-ui-1.10.4.custom.min.js"
     )
 
+    def configure_static_url(self, value):
+        if not getattr(settings, 'STATIC_URL', None):
+            self._meta.holder.STATIC_URL = value
+            return value
+        return getattr(settings, 'STATIC_URL')
+
     def configure_jquery_lib(self, value):
         if not getattr(settings, 'JQUERY_LIB', None):
             self._meta.holder.JQUERY_LIB = value
